| hunt_wls | R Documentation |
Hunt by fitting residuals on X, trained by solving a weighted least squares. See Proposition 2 of Dhawan, Guo and Shah (2026).
hunt_wls(
wls_hunt_method,
resids,
X,
X.cols = 1:ncol(X),
trim.outlier = TRUE,
arg.wls_hunt_method = NULL,
predict_fun_hunt = stats::predict
)
wls_hunt_method |
Function with signature |
resids |
Residuals (i.e., negative scores) of length n from the null model. |
X |
Covariates of dim n x p. |
X.cols |
Subset of covariates to hunt. (Default: |
trim.outlier |
If |
arg.wls_hunt_method |
Named list of additional arguments passed to
|
predict_fun_hunt |
Function with signature |
An object of class "hunt", a list with elements:
hunt.fitThe fitted hunt model produced by
wls_hunt_method.
trim.boundsThe Tukey IQR trimming bounds, or
c(-Inf, Inf) when trim.outlier = FALSE.
predict_fun_huntThe prediction function for
hunt.fit, as supplied.
X.colsThe columns of X used for the hunt, as
supplied.
hA function with signature h(X) giving the hunted
signal.
Dhawan, A., Guo, F. R. and Shah, R. D. (2026). The debiased score test: hunt-and-test for semiparametric hypotheses. arXiv:2607.28861. https://arxiv.org/abs/2607.28861
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.