| plot.dScoreTest | R Documentation |
Diagonotic plots for the test:
Histogram of \{L_i\}, where L_i = resid_i \times h_i.
\{L_i\} against the index i, where i refers to the
i-th observation in the full dataset. Only those i's in the
test split are drawn. The mean is drawn as a horizontal line.
Extremes values under the null can result in bad normal approximation.
In this case, consider setting trim.outlier.hunt=TRUE.
Residuals (negative scores) versus the hunted signal. A horizontal segment is drawn between each pair of raw hunted signal and the debiased hunted signal. If debiased gets higher, colored in red; otherwise colored in green. A regression line (blue) with a large positive slope indicates the model is misspecified.
Normalized \{L_i\} drawn in order.
## S3 method for class 'dScoreTest'
plot(x, ...)
x |
A |
... |
Further graphical parameters passed to underlying plotting functions. |
No return value; called for its side effect of producing the diagnostic plots described above.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.